@@ -1,12 +1,12 @@
 /*
-  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
-  
+
     https://imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -35,6 +35,7 @@ extern MagickExport void
 extern ModuleExport size_t
   RegisterAAIImage(void),
   RegisterARTImage(void),
+  RegisterASHLARImage(void),
   RegisterAVIImage(void),
   RegisterAVSImage(void),
   RegisterBIEImage(void),
@@ -70,6 +71,7 @@ extern ModuleExport size_t
   RegisterEXRImage(void),
   RegisterFAXImage(void),
   RegisterFITSImage(void),
+  RegisterFL32Image(void),
   RegisterFLIFImage(void),
   RegisterFPXImage(void),
   RegisterG3Image(void),
@@ -96,6 +98,7 @@ extern ModuleExport size_t
   RegisterJPEGImage(void),
   RegisterJSONImage(void),
   RegisterJP2Image(void),
+  RegisterJXLImage(void),
   RegisterLABELImage(void),
   RegisterMACImage(void),
   RegisterMAGICKImage(void),
@@ -117,6 +120,7 @@ extern ModuleExport size_t
   RegisterNULLImage(void),
   RegisterP7Image(void),
   RegisterPBMImage(void),
+  RegisterORAImage(void),
   RegisterOTBImage(void),
   RegisterPALMImage(void),
   RegisterPANGOImage(void),
@@ -200,6 +204,7 @@ extern ModuleExport size_t
 extern ModuleExport void
   UnregisterAAIImage(void),
   UnregisterARTImage(void),
+  UnregisterASHLARImage(void),
   UnregisterAVIImage(void),
   UnregisterAVSImage(void),
   UnregisterBIEImage(void),
@@ -235,6 +240,7 @@ extern ModuleExport void
   UnregisterEXRImage(void),
   UnregisterFAXImage(void),
   UnregisterFITSImage(void),
+  UnregisterFL32Image(void),
   UnregisterFLIFImage(void),
   UnregisterFPXImage(void),
   UnregisterG3Image(void),
@@ -261,6 +267,7 @@ extern ModuleExport void
   UnregisterJPEGImage(void),
   UnregisterJP2Image(void),
   UnregisterJSONImage(void),
+  UnregisterJXLImage(void),
   UnregisterLABELImage(void),
   UnregisterLOCALEImage(void),
   UnregisterMACImage(void),
@@ -283,6 +290,7 @@ extern ModuleExport void
   UnregisterNULLImage(void),
   UnregisterP7Image(void),
   UnregisterPBMImage(void),
+  UnregisterORAImage(void),
   UnregisterOTBImage(void),
   UnregisterPALMImage(void),
   UnregisterPANGOImage(void),
